@@ -4,7 +4,7 @@ APP_NAME=ubufox
 CHROME_PROVIDERS="content locale res"
 CLEAN_UP=1
 ROOT_FILES=
-ROOT_DIRS="scripts defaults components"
+ROOT_DIRS="defaults components"
 BEFORE_BUILD=
 BEFORE_PACK=
 AFTER_BUILD=
